Struct VariantStream

pub struct VariantStream {
    pub program_id: Option<u8>,
    pub bandwidth: u32,
    pub resolution: (u16, u16),
    pub frame_rate: Option<f32>,
    pub codecs: Option<String>,
    pub uri: String,
}

Fields

program_id: Option<u8>

Identifies the program or content.

bandwidth: u32

The average bitrate of the stream in bits per second.

resolution: (u16, u16)

The resolution of the video (e.g., 1440x1080).

frame_rate: Option<f32>

The frame rate of the video.

codecs: Option<String>

Specifies the codecs used for the audio and video streams.

uri: String

The URI of the m3u8 file containing the media segments for this variant.